MetQuest is a dynamic programming based algorithm for identifying all possible
pathways from metabolic networks between the source and the target metabolites. 
MetQuest requires the genome-scale metabolic reconstructions,
set of seed, source and target metabolites and the pathway length cut-off. 
MetQuest is compatible with Python 3 and is OS-independent.  

For detailed documentation, visit http://metquestdoc.readthedocs.io/